<?php

// Constants
define('THEMELIB', get_template_directory() . '/library');
define('THEMELIB_URI', get_template_directory_uri() . '/library');
define('SSLIB', get_stylesheet_directory() . '/library');
define('SSLIB_URI', get_stylesheet_directory_uri() . '/library');

// Load common functions
require_once(THEMELIB . '/common.php');

// Load thickbox
require_once(THEMELIB . '/thickbox.php');

// Load custom theme options
require_once(THEMELIB . '/theme-options.php');

if (!$theme_options['accordian'] || $theme_options['accordian'] == 0) {
	// Load accordian menu
	require_once(THEMELIB . '/accordian.php');
}

// Load theme specifics. Can be over-ridden in a child them via theme_setup()
if ( ! function_exists( 'theme_setup' ) ):
function theme_setup() {
	
	// Load language files
	load_theme_textdomain( 'purplepastels', TEMPLATEPATH . '/langs' );
	$locale = get_locale();
	$locale_file = TEMPLATEPATH . "/langs/$locale.php";
	if ( is_readable( $locale_file ) ) require_once( $locale_file );
	
	// Add post thumbnail support
	add_theme_support( 'post-thumbnails' );

	// Get the post thumbnail dimensions from Settings/Media
	set_post_thumbnail_size( get_option('thumbnail_size_w'), get_option('thumbnail_size_h') ); // box (proportional) resize mode
	
	// Set up a proper &hellip;for post extracts
	function proper_hellip($more) {
		return '&hellip;';
	}
	add_filter('excerpt_more', 'proper_hellip');

	// add custom menu support
	if ( function_exists( 'register_nav_menu' ) && !function_exists( 'register_theme_menus' )) :
	function register_theme_menus() {
		register_nav_menu( 'toptabs', __( 'Top Tabs', 'purplepastels' ) );
		register_nav_menu( 'main', __( 'Main Sidebar', 'purplepastels' ) );
		register_nav_menu( 'archive', __( 'Archives', 'purplepastels' ) );
	}
	add_action( 'init', 'register_theme_menus' );
	endif;

	// Set up customised post excerpt
	function custom_excerpt_length() {
		global $theme_options;
		if( $theme_options['custom_excerpt'] && $theme_options['custom_excerpt'] != 0 ) return $theme_options['custom_excerpt'];
		else return 100; 
	}
	add_filter('excerpt_length', 'custom_excerpt_length');
	
	// remove gallery css
	function theme_remove_gallery_css( $css ) {
		return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
	}
	add_filter( 'gallery_style', 'theme_remove_gallery_css' );
	
	// Correct image path issue in thickbox
	function theme_load_tb_fix() {
		echo "\n" . '<script type="text/javascript">tb_pathToImage = "' . site_url() . '/wp-includes/js/thickbox/loadingAnimation.gif";tb_closeImage = "' . site_url() . '/wp-includes/js/thickbox/tb-close.png";</script>'. "\n";
	}
	add_action('wp_footer', 'theme_load_tb_fix');
	
	// Set up custom post image sizes
	if( $theme_options['pt_width'] ) $pt_width = $theme_options['pt_width'];
	else $pt_width = 150;
	if( $theme_options['pt_height'] ) $pt_width = $theme_options['pt_height'];
	else $pt_height = 150;
	if( $theme_options['pt_crop'] && $theme_options['pt_crop'] == 1 ) add_image_size( 'custom', $pt_width, $pt_height, true ); 
	else add_image_size( 'custom', $pt_width, $pt_height ); 
	
	// Add support for custom background
	if( function_exists ('add_custom_background') ) add_custom_background($header_callback = 'pp_custom_background_cb', $admin_header_callback = '', $admin_image_div_callback = 'pp_admin_image_div_callback');
	
	// Header customisation/
	define('HEADER_IMAGE_WIDTH', apply_filters( 'purplepastels_header_image_width',800 ) );
	define('HEADER_IMAGE_HEIGHT', apply_filters( 'purplepastels_header_image_height', 139 ) );
	define('HEADER_IMAGE', get_bloginfo('stylesheet_directory') . '/images/header.jpg');
	define('HEADER_TEXTCOLOR', '64468B');
	define ('BACKGROUND_COLOR', 'f4f1f5');
	define ('BACKGROUND_IMAGE',  get_bloginfo('stylesheet_directory') . '/images/left.jpg');
	define ('BACKGROUND_IMAGE_THUMB_LEFT',  get_bloginfo('stylesheet_directory') . '/images/left-thumb.jpg');
	define ('BACKGROUND_IMAGE_THUMB_RIGHT',  get_bloginfo('stylesheet_directory') . '/images/right-thumb.jpg');

}
endif;
add_action( 'after_setup_theme', 'theme_setup' );

// Register widgets
if (function_exists('register_sidebar')) {
	register_sidebar(array(
		'name'=> 'Top Tabs',
		'id' => 'ppastels_tabs',
		'description' => __('Horizontal tabbed menu','purplepastels'),
		'before_widget' => '',
		'after_widget' => '',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name'=> 'Main Sidebar',
		'id' => 'ppastels_main',
		'description' => __('Default vertical sidebar','purplepastels'),
		'before_widget' => '<li id="%1$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	));
	register_sidebar(array(
		'name'=> 'Archives Sidebar',
		'id' => 'ppastels_archives',
		'description' => __('Displayed on archive listing pages only','purplepastels'),
		'before_widget' => '<li id="%1$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	));
}

/* Custom comment listing */
if ( !function_exists( 'theme_custom_comments' ) ) :
function theme_custom_comments($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	static $my_comment_count=0;
	$my_comment_count++;
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
	<div id="div-comment-<?php comment_ID(); ?>">

	<ul class="meta commentdata">
	<li><a href="<?php esc_html_e(get_comment_link($comment->comment_ID ) ) ?>"><?php printf(('%1$s') . __(' at ', 'purplepastels') . ('%2$s'), get_comment_date(), get_comment_time()) ?></a></li>
	<?php edit_comment_link((__('Edit comment ','purplepastels') .$my_comment_count),'<li class="edit">','</li>') ?></ul>

	<span class="comment-author vcard"><?php echo get_avatar($comment,$size='32'); ?>
	<?php printf(('<cite class="comment-citation">%s</cite>'), get_comment_author_link()) ?></span>

	<div class="comment_text"><?php comment_text() ?></div>
	
	<?php if ($comment->comment_approved == '0') : ?><p class="moderated"><?php _e('This comment is currently in a moderation queue.', 'purplepastels');?></p><?php endif; ?>

	<div class="reply-link"><?php comment_reply_link(array_merge( $args, array('add_below' => 'div-comment', 'depth' => $depth, 'max_depth' => $args['max_depth'], 'reply_text' =>__( 'Reply to comment ','purplepastels') .$my_comment_count))) ?></div>
	
	</div>
	<?php
}
endif;

// Custom comment form fields
if ( !function_exists( 'theme_comment_fields' ) ) :
	function theme_comment_fields($fields) {
		$req = get_option('require_name_email');
		if( $req ) $reqd = '<span class="required">' . __('*', 'scrapbook') . '</span>';

		$fields['author'] = '<p class="comment-form-author"><label class="text" for="author">' . __( 'Name', 'scrapbook' ) . $reqd . '</label><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" /></p>';

		$fields['email'] = '<p class="comment-form-email"><label class="text" for="email">' . __( 'Email', 'scrapbook' ) . $reqd . '</label><input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" />' . '</p>';

		$fields['url']   = '<p class="comment-form-url"><label class="text" for="url">' . __( 'Website', 'scrapbook') . '</label>' . '<input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>';

		return $fields;
	}
endif;
add_filter('comment_form_default_fields','theme_comment_fields');

// Custom comment form arguments
if ( ! function_exists( 'theme_comment_form_args' ) ) :
	function theme_comment_form_args($user_identity, $post_id, $req) {
		$args = array(
			'comment_notes_before' => '<p class="comment-notes"><label for="name">' . ( $req ? __( ' Required fields are marked ', 'scrapbook') . '<span class="required">' . __('*', 'scrapbook') . '</span><br />' : '' ) . __( 'Your email address will <em>never</em> be published or shared.' ) . '</p>',

			'logged_in_as' => '<p class="logged-in-as"><label for="comment">' . sprintf( __( 'Logged in as <a href="%s">%s</a>. <a href="%s" title="Log out of this account">Log out?</a></label></p>' ), admin_url( 'profile.php' ), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ),
			
			'comment_notes_after' => '',
			
			'comment_field' => '<p class="comment-form-comment"><label for="comment">' . _x( 'Comment', 'noun' ) . '</label><textarea id="comment" name="comment" cols="45" rows="8"></textarea></p>',
			'label_submit'=>'Submit Reply'
		);
		return $args;
	}
endif;

/* Custom background callback for site display */
if ( ! function_exists( 'pp_custom_background_cb' ) ) :
function pp_custom_background_cb() {
	$background = get_background_image();
	$color = get_background_color();
	if ( ! $background && ! $color )
		return;

	$style = $color ? "background-color: #$color;" : '';

	if ( $background ) {
		$image = " background-image: url('$background');";

		$repeat = get_theme_mod( 'background_repeat', 'no-repeat' );
		if ( ! in_array( $repeat, array( 'no-repeat', 'repeat-x', 'repeat-y', 'repeat' ) ) )
			$repeat = 'repeat';
		$repeat = " background-repeat: $repeat;";

		$position = get_theme_mod( 'background_position_x', 'left' );
		if ( ! in_array( $position, array( 'center', 'right', 'left' ) ) )
			$position = 'left';
		$position = " background-position: top $position;";

		$attachment = get_theme_mod( 'background_attachment', 'fixed' );
		if ( ! in_array( $attachment, array( 'fixed', 'scroll' ) ) )
			$attachment = 'scroll';
		$attachment = " background-attachment: $attachment;";

		$style .= $image . $repeat . $position . $attachment;
		
		if( $background != BACKGROUND_IMAGE ) $outer_style = 'background:transparent;';
		else $outer_style = '';
	}
	else {
		$style .= 'background-image:none;';
		$outer_style .= 'background-image:none;';
	}
?>
<style type="text/css">
html { <?php echo trim( $style ); ?> }
#outer {<?php echo $outer_style;?>}
</style>
<?php
}
endif;

/* Custom background callback for admin display */
if ( ! function_exists( 'pp_admin_image_div_callback' ) ) :
function pp_admin_image_div_callback() {
	?>
	<h3><?php _e('Background Image'); ?></h3>
	<table class="form-table">
	<tbody>
	<tr valign="top">
	<th scope="row"><?php _e('Preview'); ?></th>
	<td>
	<?php
	$background_styles = '';
	if ( $bgcolor = get_background_color() ) $background_styles .= 'background-color: #' . $bgcolor . ';';

	if ( get_background_image() ) :
		if( get_background_image() != BACKGROUND_IMAGE ) :
			$background_styles .= ' background-image: url(\'' . get_theme_mod('background_image_thumb', '') . '\');'
				. ' background-repeat: ' . get_theme_mod('background_repeat', 'repeat') . ';'
				. ' background-position: top ' . get_theme_mod('background_position_x', 'left');
		else :
			$background_styles .= ' background-image: url(' . BACKGROUND_IMAGE_THUMB_LEFT . ');'
				. ' background-repeat:no-repeat;'
				. ' background-position: left top;';
		endif;
	endif;
	?>
	<div id="custom-background-image" style="<?php echo $background_styles; ?>">
	<?php if( get_background_image() == BACKGROUND_IMAGE ) { ?>
		<div style="background:url(<?php echo BACKGROUND_IMAGE_THUMB_RIGHT;?>);background-repeat:no-repeat; background-position:right top;height:100px;">
		<?php		
	}
	
	if ( get_background_image() ) : 
	if( get_background_image() != BACKGROUND_IMAGE ) : ?>
	<img class="custom-background-image" src="<?php echo get_theme_mod('background_image_thumb', ''); ?>" style="visibility:hidden;" alt="" /><br />
	<img class="custom-background-image" src="<?php echo get_theme_mod('background_image_thumb', ''); ?>" style="visibility:hidden;" alt="" />
	<?php endif; endif; ?>
	</div>
	<?php 
}
endif;

// output header image & text CSS
if ( !function_exists( 'theme_custom_header_style' ) ) :
	function theme_custom_header_style() {
		echo '<style type="text/css" media="screen">'."\n";
		if( get_header_image() != '' ) echo '#headimg {background-image:url(' . get_header_image() . ');}';
		else echo '#headimg {background-image:none;}';
		if( get_header_textcolor() == 'blank' ) echo '#blogtitle h1 {position:absolute;top:-5000px;left:-5000px;}';
		else echo '#blogtitle,#blogtitle h1 a,#blogtitle h1 span {color:#' . get_header_textcolor() . ';}';
		echo "\n</style>\n\n";
	}
endif;

// Style header customisation in the Admin area
if ( !function_exists( 'theme_admin_header_style' ) ) :
function theme_admin_header_style() {
?>
<style type="text/css">
#headimg {
	height:139px;
	padding:0;
	margin:0;
	background-color:#CFCEF8;
	background-repeat:no-repeat;
	background-position: right top;
}
#headimg h1,#headimg #desc {
	font-family:georgia,times,'times new roman',serif;
	letter-spacing:.02em;
}
#headimg h1 {
	margin:0;
	padding:5px 0 0 15px;
	font-size:2.8em;
	font-weight:normal;
	line-height:1.2em;
	font-style:italic;
	color:#64468B;
}
#headimg a {
	text-decoration:none;
}
#headimg a:hover,#headimg a:active,#headimg a:focus {
	text-decoration:underline;
}
#headimg #desc {
	margin:0 0 20px;
	padding:8px;
	font-size:1.6em;
	text-indent:1.2em;
	color:#585359 !important;
}
</style>
<?php
}
endif;
add_custom_image_header('', 'theme_admin_header_style');
